.. _utilipy-imports-matplotlib:

*********************************************************
Matplotlib Imports (`utilipy.imports.matplotlib_imports`)
*********************************************************

.. currentmodule:: utilipy.imports.matplotlib_imports


Reference/API
=============

.. automodapi:: utilipy.imports.matplotlib_imports
